#!/bin/sh

# This script overwrites the contents of /etc/samba/smb.conf with that
# needed by the VRA (unless the file contains a 'keep' marker). It is
# intended to be called from /etc/init.d/smb whenever it runs.

CONFIG="/etc/samba/smb.conf"
SAMBA_SECURED="/opt/BUAgent/samba_secured"

# The 'keep' pattern is provided as a support tool. Should you need
# to make local modifications to /etc/samba/smb.conf, add the following
# line anywhere in the file:
#
#   #keep
#
# NOTE: Files marked with a keep marker do NOT survive a reboot. Quantum
# overwrites the file with its own version on every reboot.
KEEP_PATTERN='^[[:space:]]*#[[:space:]]*keep[[:space:]]*$'

# Check that smb.conf exists.
[ -f ${CONFIG} ] || exit 0

# Check that we can write to it... so non-root users stop here
[ -w ${CONFIG} ] || exit 0

# Check that we have to add our block into smb.conf
keep_marker=`grep ${KEEP_PATTERN} ${CONFIG}`

if [ -z "$keep_marker" ]
then
  echo "Overwriting smb.conf..."

  VENDOR_NAME=`sed -n '/^\s*vendor.name = /p' /usr/local/pancetera/etc/brand.txt|cut -d = -f2|sed 's/^\s*//'`
  PRODUCT_NAME=`sed -n '/^\s*vendor.product = /p' /usr/local/pancetera/etc/brand.txt|cut -d = -f2|sed 's/^\s*//'`
  GUEST_OK='guest ok = yes'
  VALID_USERS='# valid users = sysadmin'

  if [ -e ${SAMBA_SECURED} ]
  then
    GUEST_OK='guest ok = no'
    VALID_USERS='valid users = sysadmin'
  fi


  echo "[global]
    force user = root
    server string = \"${VENDOR_NAME} - ${PRODUCT_NAME}\"
    security = user
    printing = bsd
    load printers = no
    disable spoolss = yes
    unix password sync = yes
    #log level = 6
    log file = /var/log/samba/samba.log.%m
    max log size = 500
    debug timestamp = yes
    passdb backend = smbpasswd
    oplocks = no
    map to guest = bad user

[share]
    ${GUEST_OK}
    ${VALID_USERS}
    path = /opt/share
    comment = \"${VENDOR_NAME} - Share\"
    browseable = yes
    writeable = no
    printable = no
    public = yes
    profile acls = yes
    hide dot files = no

[mount]
    ${GUEST_OK}
    ${VALID_USERS}
    path = /opt/mount
    comment = \"${VENDOR_NAME} - VMDK disks folder\"
    browseable = no
    writeable = no
    printable = no
    public = yes
    profile acls = yes

" > "${CONFIG}"

  #=== Patching END ===#

  echo "done"
else
  echo "smb.conf is unmodified..."
fi
