#!/bin/bash
# mkuser.sh script - create samba user and directories for VV mount
# use: mkuser.sh share_root mount_root uuid user_name user_samba_password
# The idea is to create 2 directories for VV mount: /mount_root/user_name/uuid
# and pancetera vmount:                             /share_root/user_name/uuid
# Folder "user_name" can be already presented if a user is doing several VV mounts
# Folder "user_name/uuid" must be unique
# IMPORTANT PRECONDITIONS:
# 1. set samba password for the root - to be able to browse everything in linux vmdk
# 2. create samba 'share' for 'share_root' folder in /etc/samba/smb.conf file

if [ "$#" -ne 5 ]
then
  echo "Use: mkuser share_root mount_root folder_name user_name user_samba_password"
  exit 1
fi

SHARE_DIR=$1
MOUNT_DIR=$2
UUID_DIR=$3
USER_NAME=$4
USER_PASSWORD=$5

SHARE_USER_DIR=$SHARE_DIR/$USER_NAME
MOUNT_USER_DIR=$MOUNT_DIR/$USER_NAME
SHARE_USER_UUID_DIR=$SHARE_USER_DIR/$UUID_DIR
MOUNT_USER_UUID_DIR=$MOUNT_USER_DIR/$UUID_DIR

# First check for valid user - do not operate on root or sysadmin
if [ "$USER_NAME" == "root" -o "$USER_NAME" == "sysadmin" ]
then
  echo "do not use with root or sysadmin user"
  exit 1
fi

# 1. Add linux user
#echo "Create user $USER_NAME"
useradd -M $USER_NAME
RET=$?
if [ $RET -ne 0 -a $RET -ne 9 ]
then
  echo "useradd failed: $RET"
  exit 1
fi
# here useradd succeded or failed with "user alredy exists", so we have linux user

# 2. Set samba password for the linux user
#echo "Set samba password for user $USER_NAME"
echo -e "$USER_PASSWORD\n$USER_PASSWORD" | smbpasswd -sa $USER_NAME
if [ $? -ne 0 ]
then
  echo "smbpasswd failed"
  exit 1
fi

# 3. Create common samba shared folder and VV mount folder
mkdir -m 0777 -p $SHARE_DIR
mkdir -m 0777 -p $MOUNT_DIR

# 4. Create samba shared folder
#echo "Create common directory for user: $SHARE_DIR"
mkdir -m 0700 $SHARE_USER_DIR
if [ $? -eq 0 ]
then
  # directory was created, change owner
  chown $USER_NAME:$USER_NAME $SHARE_USER_DIR
fi

#echo "Create UUID_DIR: $SHARE_USER_UUID_DIR"
mkdir -m 0700 $SHARE_USER_UUID_DIR
if [ $? -ne 0 ]
then
  echo "mkdir SHARE_USER_UUID_DIR failed: $RET"
  exit 1
fi

#echo "Chown  $SHARE_USER_UUID_DIR to $USER_NAME:$USER_NAME"
chown $USER_NAME:$USER_NAME $SHARE_USER_UUID_DIR

# 5. Create VV mount folder
#echo "Create directory: $MOUNT_DIR"
mkdir -m 0700 $MOUNT_USER_DIR
if [ $? -eq 0 ]
then
  # directory was created, change owner
  chown $USER_NAME:$USER_NAME $MOUNT_USER_DIR
fi

#echo "Create UUID_DIR: $MOUNT_USER_UUID_DIR"
mkdir -m 0700 $MOUNT_USER_UUID_DIR
if [ $? -ne 0 ]
then
  echo "mkdir $MOUNT_USER_UUID_DIR failed: $RET"
  exit 1
fi

#echo "Chown  $MOUNT_USER_UUID_DIR to $USER_NAME:$USER_NAME"
chown $USER_NAME:$USER_NAME $MOUNT_USER_UUID_DIR

exit 0
