#!/bin/bash
# rmuser.sh script - cleanup after mkuser.sh
# use: rmuser.sh share_root mount_root uuid user_name
# USER_NAME folder acts as a mutex for different VV mount processes:
# if USER_NAME folder is empty we can remove this folder and samba/linux user

if [ "$#" -ne 4 ]
then
  echo "Use: rmuser.sh share_root mount_root uuid user_name"
  exit 1
fi

SHARE_DIR=$1
MOUNT_DIR=$2
UUID_DIR=$3
USER_NAME=$4

SHARE_USER_DIR=$SHARE_DIR/$USER_NAME
MOUNT_USER_DIR=$MOUNT_DIR/$USER_NAME
SHARE_USER_UUID_DIR=$SHARE_USER_DIR/$UUID_DIR
MOUNT_USER_UUID_DIR=$MOUNT_USER_DIR/$UUID_DIR

# First check for valid user - do not operate on root or sysadmin
if [ "$USER_NAME" == "root" -o "$USER_NAME" == "sysadmin" ]
then
  echo "do not use with root or sysadmin user"
  exit 1
fi

# echo "Removing uuid folders..."
rmdir $SHARE_USER_UUID_DIR
rmdir $MOUNT_USER_UUID_DIR
# remove parameters file for Dynamic Disk Mount Tool
rm -f $MOUNT_USER_DIR/$UUID_DIR".prm"

if [ "$(ls -A $SHARE_USER_DIR)" ]
then
  # Assume we have other uuid subdirs - we cannot delete the directory and user
  echo "$SHARE_USER_DIR is not empty"
  exit 0
fi

rmdir $SHARE_USER_DIR

if [ "$(ls -A $MOUNT_USER_DIR)" ]
then
  # Assume we have other uuid subdirs - we cannot delete the directory and user
  echo "$MOUNT_USER_DIR is not empty"
  exit 0
fi

rmdir $MOUNT_USER_DIR

smbpasswd -x $USER_NAME
userdel $USER_NAME

exit 0
